@@ -2,7 +2,8 @@
 #  SPDX-License-Identifier: Apache-2.0
 
 EXECUTOR_ACCOUNT_ID = "SCT_EXECUTOR_ACCOUNT_ID"
-CACHE_INVALIDATOR = "SCT_CACHE_INVALIDATOR"
+TASK_IDEMPOTENCY_TOKEN = "SCT_TASK_IDEMPOTENCY_TOKEN"
+RUN_IDEMPOTENCY_TOKEN = "SCT_RUN_IDEMPOTENCY_TOKEN"
 EXECUTION_MODE = "SCT_EXECUTION_MODE"
 PUPPET_ACCOUNT_ID = "SCT_PUPPET_ACCOUNT_ID"
 SINGLE_ACCOUNT_ID = "SCT_SINGLE_ACCOUNT_ID"
