@@ -114,6 +114,9 @@ SERVICE_CATALOG_SEARCH_PRODUCTS_AS_ADMIN_PER_REGION_OF_ACCOUNT = (
 SERVICE_CATALOG_DESCRIBE_PRODUCT_AS_ADMIN_PER_REGION_OF_ACCOUNT = (
     "SERVICE_CATALOG_DESCRIBE_PRODUCT_AS_ADMIN" + PER_REGION_OF_ACCOUNT
 )
+SERVICE_CATALOG_DESCRIBE_PROVISIONING_ARTEFACT_PER_REGION_OF_ACCOUNT = (
+    "SERVICE_CATALOG_DESCRIBE_PROVISIONING_ARTEFACT" + PER_REGION_OF_ACCOUNT
+)
 SERVICE_CATALOG_DESCRIBE_PROVISIONING_PARAMETERS_PER_REGION_OF_ACCOUNT = (
     "SERVICE_CATALOG_DESCRIBE_PROVISIONING_PARAMETERS" + PER_REGION_OF_ACCOUNT
 )
@@ -387,6 +390,7 @@ def create(section_name, parameters_to_use, puppet_account_id):
             resources = [
                 SERVICE_CATALOG_SEARCH_PRODUCTS_AS_ADMIN_PER_REGION_OF_ACCOUNT,
                 SERVICE_CATALOG_DESCRIBE_PRODUCT_AS_ADMIN_PER_REGION_OF_ACCOUNT,
+                SERVICE_CATALOG_DESCRIBE_PROVISIONING_ARTEFACT_PER_REGION_OF_ACCOUNT,
             ]
 
     elif section_name == constants.DESCRIBE_PROVISIONING_PARAMETERS:
