@@ -2,7 +2,6 @@
 #  SPDX-License-Identifier: Apache-2.0
 
 import json
-from servicecatalog_puppet import serialisation_utils, remote_config
 import logging
 import os
 import shutil
@@ -22,12 +21,17 @@ from betterboto import client as betterboto_client
 from colorclass import Color
 from luigi import LuigiStatusCode
 
-from servicecatalog_puppet import config
-from servicecatalog_puppet import constants
-from servicecatalog_puppet import environmental_variables
+from servicecatalog_puppet import (
+    config,
+    constants,
+    environmental_variables,
+    remote_config,
+    serialisation_utils,
+)
 from servicecatalog_puppet.waluigi import runner_factory
 from servicecatalog_puppet.workflow import tasks
 
+
 logger = logging.getLogger(constants.PUPPET_LOGGER_NAME)
 
 
@@ -121,7 +125,12 @@ def run_tasks(
         config.get_scheduler_algorithm(),
     )
 
-    cache_invalidator = os.environ.get(environmental_variables.CACHE_INVALIDATOR)
+    task_idempotency_token = os.environ.get(
+        environmental_variables.TASK_IDEMPOTENCY_TOKEN
+    )
+    run_idempotency_token = os.environ.get(
+        environmental_variables.RUN_IDEMPOTENCY_TOKEN
+    )
 
     has_failures = len(glob("results/failure/*", recursive=True))
     has_spoke_failures = False
@@ -129,7 +138,8 @@ def run_tasks(
     if execution_mode == constants.EXECUTION_MODE_HUB:
         logger.info("Checking spoke executions...")
         all_run_deploy_in_spoke_tasks = glob(
-            f"output/RunDeployInSpokeTask/**/{cache_invalidator}.json", recursive=True,
+            f"output/RunDeployInSpokeTask/**/{run_idempotency_token}.json",  # TODO EPF
+            recursive=True,
         )
         n_all_run_deploy_in_spoke_tasks = len(all_run_deploy_in_spoke_tasks)
         index = 0
@@ -175,19 +185,19 @@ def run_tasks(
 
     dry_run_tasks = (
         glob(
-            f"output/ProvisionProductDryRunTask/**/{cache_invalidator}.json",
+            f"output/ProvisionProductDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
             recursive=True,
         )
         + glob(
-            f"output/TerminateProductDryRunTask/**/{cache_invalidator}.json",
+            f"output/TerminateProductDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
             recursive=True,
         )
         + glob(
-            f"output/ProvisionStackDryRunTask/**/{cache_invalidator}.json",
+            f"output/ProvisionStackDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
             recursive=True,
         )
         + glob(
-            f"output/TerminateStackDryRunTask/**/{cache_invalidator}.json",
+            f"output/TerminateStackDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
             recursive=True,
         )
     )
@@ -248,7 +258,7 @@ def run_tasks(
         elif is_list_launches == "json":
             results = dict()
             for filename in glob(
-                f"output/ProvisionProductDryRunTask/**/{cache_invalidator}.json",
+                f"output/ProvisionProductDryRunTask/**/{task_idempotency_token}.json",  # TODO EPF
                 recursive=True,
             ):
                 result = serialisation_utils.json_loads(open(filename, "r").read())
